/*
Used for configuring libkcddb.
*/

/********************************************************************************
** Form generated from reading UI file 'cddbconfigwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CDDBCONFIGWIDGET_H
#define UI_CDDBCONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kseparator.h"

QT_BEGIN_NAMESPACE

class Ui_CDDBConfigWidgetBase
{
public:
    QVBoxLayout *vboxLayout;
    QTabWidget *tabWidget2;
    QWidget *tabLookup;
    QVBoxLayout *gridLayout_4;
    QCheckBox *kcfg_MusicBrainzLookupEnabled;
    QCheckBox *kcfg_FreedbLookupEnabled;
    KSeparator *kseparator;
    QGroupBox *freedbServerBox;
    QFormLayout *formLayout;
    QLabel *TextLabel7;
    QHBoxLayout *horizontalLayout_6;
    QLineEdit *kcfg_hostname;
    QLabel *textLabel3_3;
    QSpinBox *kcfg_port;
    QLabel *TextLabel9;
    QHBoxLayout *horizontalLayout_7;
    QComboBox *kcfg_FreedbLookupTransport;
    QPushButton *mirrorListButton;
    QWidget *cacheLocationsParent;
    QWidget *tabSubmit;
    QVBoxLayout *gridLayout_2;
    QHBoxLayout *horizontalLayout_5;
    QSpacerItem *horizontalSpacer;
    QLabel *textLabel1;
    QLineEdit *kcfg_emailAddress;
    QSpacerItem *horizontalSpacer_2;
    QGroupBox *groupBox;
    QFormLayout *formLayout_2;
    QLabel *textLabel2;
    QHBoxLayout *horizontalLayout;
    QLineEdit *kcfg_httpSubmitServer;
    QLabel *textLabel3_2;
    QSpinBox *kcfg_httpSubmitPort;

    void setupUi(QWidget *CDDBConfigWidgetBase)
    {
        if (CDDBConfigWidgetBase->objectName().isEmpty())
            CDDBConfigWidgetBase->setObjectName("CDDBConfigWidgetBase");
        vboxLayout = new QVBoxLayout(CDDBConfigWidgetBase);
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        vboxLayout->setObjectName("vboxLayout");
        tabWidget2 = new QTabWidget(CDDBConfigWidgetBase);
        tabWidget2->setObjectName("tabWidget2");
        tabWidget2->setDocumentMode(true);
        tabLookup = new QWidget();
        tabLookup->setObjectName("tabLookup");
        gridLayout_4 = new QVBoxLayout(tabLookup);
        gridLayout_4->setObjectName("gridLayout_4");
        kcfg_MusicBrainzLookupEnabled = new QCheckBox(tabLookup);
        kcfg_MusicBrainzLookupEnabled->setObjectName("kcfg_MusicBrainzLookupEnabled");

        gridLayout_4->addWidget(kcfg_MusicBrainzLookupEnabled);

        kcfg_FreedbLookupEnabled = new QCheckBox(tabLookup);
        kcfg_FreedbLookupEnabled->setObjectName("kcfg_FreedbLookupEnabled");

        gridLayout_4->addWidget(kcfg_FreedbLookupEnabled);

        kseparator = new KSeparator(tabLookup);
        kseparator->setObjectName("kseparator");

        gridLayout_4->addWidget(kseparator);

        freedbServerBox = new QGroupBox(tabLookup);
        freedbServerBox->setObjectName("freedbServerBox");
        freedbServerBox->setFlat(true);
        formLayout = new QFormLayout(freedbServerBox);
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::FieldGrowthPolicy::FieldsStayAtSizeHint);
        formLayout->setFormAlignment(Qt::AlignmentFlag::AlignHCenter|Qt::AlignmentFlag::AlignTop);
        TextLabel7 = new QLabel(freedbServerBox);
        TextLabel7->setObjectName("TextLabel7");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, TextLabel7);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        kcfg_hostname = new QLineEdit(freedbServerBox);
        kcfg_hostname->setObjectName("kcfg_hostname");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_hostname->sizePolicy().hasHeightForWidth());
        kcfg_hostname->setSizePolicy(sizePolicy);

        horizontalLayout_6->addWidget(kcfg_hostname);

        textLabel3_3 = new QLabel(freedbServerBox);
        textLabel3_3->setObjectName("textLabel3_3");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(textLabel3_3->sizePolicy().hasHeightForWidth());
        textLabel3_3->setSizePolicy(sizePolicy1);

        horizontalLayout_6->addWidget(textLabel3_3);

        kcfg_port = new QSpinBox(freedbServerBox);
        kcfg_port->setObjectName("kcfg_port");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(kcfg_port->sizePolicy().hasHeightForWidth());
        kcfg_port->setSizePolicy(sizePolicy2);
        kcfg_port->setMaximum(64000);
        kcfg_port->setValue(8880);

        horizontalLayout_6->addWidget(kcfg_port);


        formLayout->setLayout(0, QFormLayout::ItemRole::FieldRole, horizontalLayout_6);

        TextLabel9 = new QLabel(freedbServerBox);
        TextLabel9->setObjectName("TextLabel9");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, TextLabel9);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        kcfg_FreedbLookupTransport = new QComboBox(freedbServerBox);
        kcfg_FreedbLookupTransport->addItem(QString());
        kcfg_FreedbLookupTransport->addItem(QString());
        kcfg_FreedbLookupTransport->setObjectName("kcfg_FreedbLookupTransport");

        horizontalLayout_7->addWidget(kcfg_FreedbLookupTransport);

        mirrorListButton = new QPushButton(freedbServerBox);
        mirrorListButton->setObjectName("mirrorListButton");

        horizontalLayout_7->addWidget(mirrorListButton);


        formLayout->setLayout(1, QFormLayout::ItemRole::FieldRole, horizontalLayout_7);


        gridLayout_4->addWidget(freedbServerBox);

        cacheLocationsParent = new QWidget(tabLookup);
        cacheLocationsParent->setObjectName("cacheLocationsParent");

        gridLayout_4->addWidget(cacheLocationsParent);

        tabWidget2->addTab(tabLookup, QString());
        tabSubmit = new QWidget();
        tabSubmit->setObjectName("tabSubmit");
        gridLayout_2 = new QVBoxLayout(tabSubmit);
        gridLayout_2->setObjectName("gridLayout_2");
        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer);

        textLabel1 = new QLabel(tabSubmit);
        textLabel1->setObjectName("textLabel1");

        horizontalLayout_5->addWidget(textLabel1);

        kcfg_emailAddress = new QLineEdit(tabSubmit);
        kcfg_emailAddress->setObjectName("kcfg_emailAddress");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(kcfg_emailAddress->sizePolicy().hasHeightForWidth());
        kcfg_emailAddress->setSizePolicy(sizePolicy3);
        kcfg_emailAddress->setMinimumSize(QSize(250, 0));

        horizontalLayout_5->addWidget(kcfg_emailAddress);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_2);


        gridLayout_2->addLayout(horizontalLayout_5);

        groupBox = new QGroupBox(tabSubmit);
        groupBox->setObjectName("groupBox");
        groupBox->setFlat(true);
        formLayout_2 = new QFormLayout(groupBox);
        formLayout_2->setObjectName("formLayout_2");
        formLayout_2->setFieldGrowthPolicy(QFormLayout::FieldGrowthPolicy::FieldsStayAtSizeHint);
        formLayout_2->setFormAlignment(Qt::AlignmentFlag::AlignHCenter|Qt::AlignmentFlag::AlignTop);
        textLabel2 = new QLabel(groupBox);
        textLabel2->setObjectName("textLabel2");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, textLabel2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        kcfg_httpSubmitServer = new QLineEdit(groupBox);
        kcfg_httpSubmitServer->setObjectName("kcfg_httpSubmitServer");

        horizontalLayout->addWidget(kcfg_httpSubmitServer);

        textLabel3_2 = new QLabel(groupBox);
        textLabel3_2->setObjectName("textLabel3_2");
        sizePolicy1.setHeightForWidth(textLabel3_2->sizePolicy().hasHeightForWidth());
        textLabel3_2->setSizePolicy(sizePolicy1);

        horizontalLayout->addWidget(textLabel3_2);

        kcfg_httpSubmitPort = new QSpinBox(groupBox);
        kcfg_httpSubmitPort->setObjectName("kcfg_httpSubmitPort");

        horizontalLayout->addWidget(kcfg_httpSubmitPort);


        formLayout_2->setLayout(0, QFormLayout::ItemRole::FieldRole, horizontalLayout);


        gridLayout_2->addWidget(groupBox);

        tabWidget2->addTab(tabSubmit, QString());

        vboxLayout->addWidget(tabWidget2);

#if QT_CONFIG(shortcut)
        TextLabel7->setBuddy(kcfg_hostname);
        TextLabel9->setBuddy(kcfg_FreedbLookupTransport);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kcfg_hostname, kcfg_port);
        QWidget::setTabOrder(kcfg_port, kcfg_FreedbLookupTransport);

        retranslateUi(CDDBConfigWidgetBase);

        tabWidget2->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(CDDBConfigWidgetBase);
    } // setupUi

    void retranslateUi(QWidget *CDDBConfigWidgetBase)
    {
        CDDBConfigWidgetBase->setWindowTitle(tr2i18n("CDDB Settings", nullptr));
        kcfg_MusicBrainzLookupEnabled->setText(tr2i18n("Enable MusicBrainz lookup", nullptr));
        kcfg_FreedbLookupEnabled->setText(tr2i18n("Enable freedb lookup", nullptr));
        freedbServerBox->setTitle(tr2i18n("Freedb Server", nullptr));
        TextLabel7->setText(tr2i18n("Freedb server:", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_hostname->setWhatsThis(tr2i18n("Name of CDDB server which will be used to look up CD information.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_hostname->setText(tr2i18n("gnudb.gnudb.org", nullptr));
        textLabel3_3->setText(tr2i18n("Port:", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_port->setWhatsThis(tr2i18n("Port to connect to on CDDB server.", nullptr));
#endif // QT_CONFIG(whatsthis)
        TextLabel9->setText(tr2i18n("&Transport:", nullptr));
        kcfg_FreedbLookupTransport->setItemText(0, tr2i18n("CDDB", nullptr));
        kcfg_FreedbLookupTransport->setItemText(1, tr2i18n("HTTP", nullptr));

#if QT_CONFIG(whatsthis)
        kcfg_FreedbLookupTransport->setWhatsThis(tr2i18n("Type of lookup which should be tried at the CDDB server.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mirrorListButton->setText(tr2i18n("Show &Mirror List", nullptr));
        tabWidget2->setTabText(tabWidget2->indexOf(tabLookup), tr2i18n("&Lookup", nullptr));
        textLabel1->setText(tr2i18n("Email address:", nullptr));
        groupBox->setTitle(tr2i18n("Submit Method", nullptr));
        textLabel2->setText(tr2i18n("Server:", nullptr));
        textLabel3_2->setText(tr2i18n("Port:", nullptr));
        tabWidget2->setTabText(tabWidget2->indexOf(tabSubmit), tr2i18n("&Submit", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CDDBConfigWidgetBase: public Ui_CDDBConfigWidgetBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CDDBCONFIGWIDGET_H

